"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _test = require("@playwright/test");
var _path = _interopRequireDefault(require("path"));
var _readConfigFile = require("../readConfigFile");
var _configUtils = require("./config-utils");
const {
  browsers,
  trace,
  video,
  isAuthMode,
  openReportOn,
  reportPath,
  bddMode,
  expectTimeout,
  testTimeout,
  authFilePath,
  viewport,
  featureFilesFolder,
  stepDefinitionsFolder,
  testIdAttribute,
  globalTimeout
} = (0, _readConfigFile.generateConfigFromFile)();
const projects = (0, _configUtils.getProjects)({
  browsers,
  isAuthMode,
  authFilePath,
  expectTimeout,
  testTimeout,
  viewport
});
const testDir = (0, _configUtils.getTestDir)(bddMode, process.cwd(), {
  featureFilesFolder,
  stepDefinitionsFolder
});
const use = {
  trace,
  video,
  viewport,
  testIdAttribute
};

/**
 * Playwright configuration object
 *
 * @returns {import('@playwright/test').PlaywrightTestConfig}
 */
function getPlaywrightConfig() {
  return {
    testDir,
    globalTimeout: globalTimeout || 3600000,
    outputDir: _path.default.join(process.cwd(), 'uat', 'test-results'),
    fullyParallel: true,
    forbidOnly: !!process.env.CI,
    retries: process.env.CI ? 2 : 0,
    reporter: [['html', {
      outputFolder: reportPath,
      open: openReportOn
    }], ['list'], ['./custom-reporter.js']],
    timeout: testTimeout,
    expect: {
      timeout: expectTimeout
    },
    use,
    projects: isAuthMode ? [{
      name: 'setup',
      testMatch: /.*\.setup\.js/,
      testDir: _path.default.join(process.cwd(), 'uat'),
      teardown: 'cleanup'
    }, {
      name: 'cleanup',
      testMatch: /.*\.teardown\.js/,
      testDir: _path.default.join(process.cwd(), 'uat')
    }, ...projects] : [...projects]
  };
}
var _default = exports.default = (0, _test.defineConfig)(getPlaywrightConfig());